@@ -101,14 +101,15 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
-"global_8h.html#a3c30e6a36a12ab02e97c7a0014d578d0",
-"impl-node_8c.html#a15f24a773042bebdd3f5341791be7e13",
-"keys_8h.html#aff405f056c4afbeb87df6f663178b993",
-"page_streams.html#ssec_produce",
-"stream_8c.html#ac1d281db6111363227781192d2eb56c7",
-"structpw__core__methods.html#a7e77a9289cd4ba827a7082109d207459",
-"structpw__properties.html"
+"core_8h.html#a02b3e6ff573afd1efba25efc8bbb2538",
+"global_8c.html#a457beceeca2fc2e7907289e766a0da13",
+"impl-module_8h.html#a0228a5d6fa88526e9072c4194ce9ad04",
+"keys_8h.html#adaf914599e9ddeab31f925204323f678",
+"page_proxy.html#sec_page_proxy_bind",
+"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb",
+"structpw__core__events.html#a6cf547297486e97c8969a1e08d837955",
+"structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad",
+"utils_8h.html#a8869815cdd42998571019730afd248ff"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
